# assistants

The ***assistants*** project aims to provide useful reporting tools for scouts.

## Where to get it

The source code for the project is hosted on GitHub at
[the-scouts/assistants](https://github.com/the-scouts/assistants)

## Dependencies

- [pandas](https://github.com/pandas-dev/pandas/) - for data wrangling
- [pyarrow](https://github.com/apache/arrow/tree/master/python/) - for fast on-disk storage
- [openpyxl](https://foss.heptapod.net/openpyxl/openpyxl/) - for writing to excel workbooks
- [compass-interface-core](https://github.com/the-scouts/compass-interface-core/) - for integrating with Compass

## License

***assistants*** is naturally
[open source](https://github.com/the-scouts/assistants) and is
licensed under the **[MIT license](https://choosealicense.com/licenses/mit/)**.
